.. image:: https://travis-ci.org/timcera/pyslice.svg?branch=master
    :target: https://travis-ci.org/timcera/pyslice
    :height: 20

.. image:: https://coveralls.io/repos/timcera/pyslice/badge.png?branch=master
    :target: https://coveralls.io/r/timcera/pyslice?branch=master
    :height: 20

.. image:: https://img.shields.io/pypi/v/pyslice.svg
    :alt: Latest release
    :target: https://pypi.python.org/pypi/pyslice

.. image:: http://img.shields.io/badge/license-BSD-lightgrey.svg
    :alt: BSD-3 clause license
    :target: https://pypi.python.org/pypi/pyslice/
.. image:: http://img.shields.io/pypi/dd/pyslice.svg
    :alt: pyslice downloads
    :target: https://pypi.python.org/pypi/pyslice/
